Learn R Programming

rotl (version 0.5.0)

gol_about: Information about the Graph of Life

Description

Graph of Life

Usage

gol_about(...)

Arguments

...
additional arguments to customize the API call (see ?rotl for more information)

Value

  • An invisible list of graph attributes:
    • graph_num_source_trees
    {The number of unique source trees in the graph.}
  • graph_taxonomy_version
  • {The version of the taxonomy used to initialize the graph.}
  • graph_num_tips
  • {The number of terminal (tip) taxa in the graph.}
  • graph_root_name
  • {The taxonomic name of the root node of the graph.}
  • graph_root_node_id
  • {The node ID of the root node of the graph.}
  • graph_root_ott_id
  • {The OpenTree Taxonomy ID (ottID) of the root node of the graph.}

Details

Basic information about the Graph of Life.

Returns summary information about the entire graph database, including identifiers for the taxonomy and source trees used to build it.

Examples

Run this code
res <- gol_about()

Run the code above in your browser using DataLab