Learn R Programming

rotl (version 3.0.0)

synonyms.match_names: List the synonyms for a given name

Description

When querying the Taxonomic Name Resolution Services for a particular taxonomic name, the API returns as possible matches all names that include the queried name as a possible synonym. This function allows you to explore other synonyms for an accepted name, and allows you to determine why the name you queried is returning an accepted synonym.

Usage

"synonyms"(tax, row_number, taxon_name, ott_id, ...)

Arguments

tax
a data frame generated by the tnrs_match_names function
row_number
the row number corresponding to the name for which to list the synonyms
taxon_name
the taxon name corresponding to the name for which to list the synonyms
ott_id
the ott id corresponding to the name for which to list the synonyms
...
currently ignored

Value

a list whose elements are all synomym names (as vectors of character) for the taxonomic names that match the query (the names of the elements of the list).

Details

To list synonyms for a given taxonomic name, you need to provide the object resulting from a call to the tnrs_match_names function, as well as one of either the row number corresponding to the name in this object, the name itself (as used in the original query), or the ott_id listed for this name. Otherwise, the synonyms for all the currently matched names are returned.

Examples

Run this code
## Not run: 
#    echino <- tnrs_match_names(c("Diadema", "Acanthaster", "Fromia"))
#    ## These 3 calls are identical
#    synonyms(echino, taxon_name="Acanthaster")
#    synonyms(echino, row_number=2)
#    synonyms(echino, ott_id=337928)
# ## End(Not run)

Run the code above in your browser using DataLab