Learn R Programming

rotl (version 3.0.0)

tax_lineage: Lineage of a taxon

Description

Extract the lineage information (higher taxonomy) from an object returned by taxonomy_taxon_info.

Usage

tax_lineage(tax, ...)
"tax_lineage"(tax, ...)

Arguments

tax
an object created by taxonomy_taxon_info.
...
additional arguments (currently unused).

Value

A list with one slot per taxon that contains a data frame with 3 columns: the taxonomy rank, the name, and unique name for all taxa included in the lineage of the taxon up to the root of the tree.

Details

The object passed to this function must have been created using the argument include_lineage=TRUE.