Learn R Programming

rotl (version 0.5.0)

tax_rank: Methods for Taxonomy

Description

Methods for dealing with objects returned by functions dealing with the Taxonomy and the Taxonomic Name Resolution Services APIs.

Usage

tax_rank(tax)

ott_taxon_name(tax)

ott_id(tax, ...)

synonyms(tax, ...)

Arguments

tax
an object returned by taxonomy_taxon, taxonomy_lica, or tnrs_match_names
...
additional arguments (see tnrs_match_names)

Details

This is the page for the generic methods. See the help pages for taxonomy_taxon, taxonomy_lica, and tnrs_match_names for more information.