Learn R Programming

rotl (version 3.0.0)

taxon_external_IDs: Get external identifiers for data associated with an Open Tree taxon

Description

The Open Tree taxonomy is a synthesis of multiple reference taxonomies. This function retrieves identifiers to external taxonomic records that have contributed the rank, position and definition of a given Open Tree taxon.

Usage

taxon_external_IDs(taxon_id)

Arguments

taxon_id
An open tree study ID

Value

a data.frame in which each row represents a unique record in an external databse. The column "source" provides and abbreviated name for the database, and "id" the unique ID for the record.

See Also

tnrs_matchnames, which can be used to search for taxa by name.

taxonomy_taxon, for more information about a given taxon.

Examples

Run this code
## Not run: 
#    gibbon_IDs <- taxon_external_IDs(712902) 
# ## End(Not run)

Run the code above in your browser using DataLab