Learn R Programming

rotl (version 0.5.0)

taxonomy_about: About the Open Tree Taxonomy

Description

Summary information about the Open Tree Taxaonomy (OTT)

Usage

taxonomy_about(...)

Arguments

...
additional arguments to customize the API request (see rotl package documentation).

Value

  • A list with at least the version and the location of the taxonomy source files

Details

Return metadata and information about the taxonomy itself. Currently, the available metadata is fairly sparse, but includes (at least) the eversion, and the location from which the complete taxonomy source files can be downloaded.

Examples

Run this code
taxonomy_about()

Run the code above in your browser using DataLab