Learn R Programming

rotl (version 0.5.0)

taxonomy_lica: Taxonomic LICA

Description

Taxonomic Least Inclusive Common Ancestor

Usage

taxonomy_lica(ott_ids = NULL, ...)

## S3 method for class 'taxon_lica': tax_rank(tax)

## S3 method for class 'taxon_lica': ott_taxon_name(tax)

## S3 method for class 'taxon_lica': ott_id(tax, ...)

Arguments

ott_ids
a vector of ott ids for the taxa whose LICA is to be found (numeric).
...
additional arguments to customize the API request (see rotl package documentation).
tax
an object generated by the taxonomy_lica function

Value

    • taxonomy_lica
    { returns a list about the taxonomic information relating to the LICA for the ott_ids provided. }
  • tax_rank
  • { returns a character vector of the taxonomic rank for the LICA. }
  • ott_taxon_name
  • { returns a character vector the Open Tree Taxonomy name for the LICA. }
  • ott_id
  • { returns a numeric vector of the ott id for the LICA. }

Details

Given a set of ott ids, get the taxon that is the least inclusive common ancestor (the LICA) of all the identified taxa. A taxonomic LICA is analogous to a most recent common ancestor (MRCA) in a phylogenetic tree.

Examples

Run this code
req <- taxonomy_lica(ott_ids=c(515698,590452,409712,643717))
tax_rank(req)
ott_taxon_name(req)
ott_id(req)

Run the code above in your browser using DataLab