Learn R Programming

rotl (version 0.5.0)

taxonomy_taxon: Taxon information

Description

Information about taxa.

Usage

taxonomy_taxon(ott_ids, include_lineage = FALSE,
  list_terminal_descendants = FALSE, ...)

## S3 method for class 'taxon_info': tax_rank(tax)

## S3 method for class 'taxon_info': ott_taxon_name(tax)

## S3 method for class 'taxon_info': synonyms(tax, ...)

Arguments

ott_ids
the ott ids of the taxon of interest (numeric or character containing only numbers)
include_lineage
whether to include information about all the higher level taxa that include the ott_ids. Default FALSE.
list_terminal_descendants
whether to include the list of terminal ott_ids contained in the ott_ids provided.
...
additional arguments to customize the API request (see rotl package documentation).
tax
an object generated by the taxonomy_taxon function

Value

  • taxonomy_taxon returns a list detailing information about the taxa. tax_rank and ott_taxon_name return a vector. synonyms returns a list whose elements are the synonyms for each of the ott_id requested.

Details

Given a vector of ott ids, taxonomy_taxon returns information about the specified taxa.

The functions tax_rank, ott_taxon_name, and synonyms can extract this information from an object created by the taxonomy_taxon function.

See Also

tnrs_match_names to obtain ott_id from a taxonomic name.

Examples

Run this code
req <- taxonomy_taxon(ott_id=515698)
tax_rank(req)
ott_taxon_name(req)
synonyms(req)

Run the code above in your browser using DataLab