powered by
gol_about(...)
Returns summary information about the entire graph database, including identifiers for the taxonomy and source trees used to build it.
res <- gol_about()
Run the code above in your browser using DataLab