## Not run:
# ## To match a study for which the identifier is already known
# one_study <- studies_find_studies(property="ot:studyId", value="pg_719")
# list_trees(one_study)
#
# ## To find studies pertaining to Mammals
# mammals <- studies_find_studies(property="ot:focalCladeOTTTaxonName",
# value="mammalia")
# ## To extract the tree identifiers for each of the studies
# list_trees(mammals)
# ## ... or for a given study
# list_trees(mammals, "ot_308")
#
# ## Just the identifiers without other information about the studies
# mammals <- studies_find_studies(property="ot:focalCladeOTTTaxonName",
# value="mammalia", detailed=FALSE)
# ## End(Not run)
Run the code above in your browser using DataLab