## Not run:
# res <- studies_find_trees(property="ot:ottTaxonName", value="Drosophilia",
# detailed=FALSE)
# ## summary of the trees and associated studies that match this criterion
# res
# ## With metadata about the studies (default)
# res <- studies_find_trees(property="ot:ottTaxonName", value="Drosophilia",
# detailed=TRUE)
# ## The list of trees for each study that match the search criteria
# list_trees(res)
# ## the trees for a given study
# list_trees(res, study_id = "pg_2769")
# ## End(Not run)
Run the code above in your browser using DataLab