A list with one slot per taxon that contains a data frame
with 3 columns: the taxonomy rank, the name, and unique name
for all taxa included in the lineage of the taxon up to the
root of the tree.
Details
The object passed to this function must have been created using
the argument include_lineage=TRUE.