Learn R Programming

rotl (version 3.0.0)

taxonomy_mrca: Taxonomic MRCA

Description

Taxonomic Least Inclusive Common Ancestor (MRCA)

Usage

taxonomy_mrca(ott_ids = NULL, ...)
"tax_rank"(tax, ...)
"tax_name"(tax, ...)
"ott_id"(tax, ...)
"unique_name"(tax, ...)
"tax_sources"(tax, ...)
"flags"(tax, ...)
"is_suppressed"(tax, ...)

Arguments

ott_ids
a vector of ott ids for the taxa whose MRCA is to be found (numeric).
...
additional arguments to customize the API request (see rotl package documentation).
tax
an object generated by the taxonomy_mrca function

Value

  • taxonomy_mrca returns a list about the taxonomic information relating to the MRCA for the ott_ids provided.
  • tax_rank returns a character vector of the taxonomic rank for the MRCA.
  • tax_name returns a character vector the Open Tree Taxonomy name for the MRCA.
  • ott_id returns a numeric vector of the ott id for the MRCA.

Details

Given a set of OTT ids, get the taxon that is the most recent common ancestor (the MRCA) of all the identified taxa.

Examples

Run this code
## Not run: 
# req <- taxonomy_mrca(ott_ids=c(515698,590452,643717))
# tax_rank(req)
# tax_name(req)
# ott_id(req)
# ## End(Not run)

Run the code above in your browser using DataLab