tnrs_match_names(names = NULL, context_name = NULL, do_approximate_matching = TRUE, ids = NULL, include_suppressed = FALSE, ...)tnrs_contexts.FALSE will greatly improve
speed. Default, however, is TRUE.rotl package documentation).attr(object,
"original_response")).
This service uses taxonomic contexts to disambiguate homonyms and
misspelled names; a context may be specified using the
context_name argument. If no context is specified, then the
context will be inferred (i.e., the shallowest taxonomic context
that contains all unambiguous names in the input). Taxonomic
contexts are uncontested higher taxa that have been selected to
allow limits to be applied to the scope of TNRS searches
(e.g. 'match names only within flowering plants'). Once a context
has been identified (either user-specified or inferred), all taxon
name matches will performed only against taxa within that
context. For a list of available taxonomic contexts, see
tnrs_contexts.
A name is considered unambiguous if it is not a synonym and has only one exact match to any taxon name in the entire taxonomy.
Several functions listed in the See also section can be used to inspect and manipulate the object generated by this function.
inspect.match_names,
update.match_names,
synonyms.match_names.
## Not run:
# deuterostomes <- tnrs_match_names(names=c("echinodermata", "xenacoelomorpha",
# "chordata", "hemichordata"))
# ## End(Not run)
Run the code above in your browser using DataLab