Learn R Programming

rotl (version 0.5.0)

tnrs_match_names: Match names to the Open Tree Taxonomy

Description

Match taxonomic names to the Open Tree Taxonomy.

Usage

tnrs_match_names(names = NULL, context_name = NULL,
  do_approximate_matching = TRUE, ids = NULL, include_deprecated = FALSE,
  include_dubious = FALSE, ...)

Arguments

names
taxon names to be queried (character vector)
context_name
name of the taxonomic context to be searched (length-one character vector). Must match (case sensitive) one of the values returned by tnrs_contexts.
do_approximate_matching
A logical indicating whether or not to perform approximate string (a.k.a. fuzzy) matching. Using FALSE will greatly improve speed. Default, however, is TRUE.
ids
An array of ids to use for identifying names. These will be assigned to each name in the names array. If ids is provided, then ids and names must be identical in length.
include_deprecated
A boolean indicating whether or not to include deprecated taxa in the search.
include_dubious
Whether to include so-called 'dubious' taxa--those which are not accepted by OTT.
...
additional arguments to customize the API request (see rotl package documentation).

Value

  • A data frame summarizing the results of the query. The original query output is appended as an attribute to the returned object (and can be obtained using attr(object, "original_response")).

Details

Accepts one or more taxonomic names and returns information about potential matches for these names to known taxa in the Open Tree Taxononmy.

This service uses taxonomic contexts to disambiguate homonyms and misspelled names; a context may be specified using the context_name argument. If no context is specified, then the context will be inferred (i.e., the shallowest taxonomic context that contains all unambiguous names in the input). Taxonomic contexts are uncontested higher taxa that have been selected to allow limits to be applied to the scope of TNRS searches (e.g. 'match names only within flowering plants'). Once a context has been identified (either user-specified or inferred), all taxon name matches will performed only against taxa within that context. For a list of available taxonomic contexts, see tnrs_contexts.

A name is considered unambiguous if it is not a synonym and has only one exact match to any taxon name in the entire taxonomy.

Several functions listed in the See also section can be used to inspect and manipulate the object generated by this function.

See Also

inspect.match_names, update.match_names, synonyms.match_names.

Examples

Run this code
deuterostomes <- tnrs_match_names(names=c("echinodermata", "xenacoelomorpha",
                                            "chordata", "hemichordata"))

Run the code above in your browser using DataLab