Learn R Programming

rotl (version 0.5.0)

tol_about: Information about the Tree of Life

Description

Basic information about the Open Tree of Life (the synthetic tree)

Usage

tol_about(study_list = FALSE, ...)

Arguments

study_list
Whether to return the list of source studies. (Logical, default = FALSE).
...
additional arguments to customize the API call (see rotl for more information).

Value

  • An invisible list of synthetic tree summary statistics:

    • tree_id
    {The name identifier of the synthetic tree.}

  • date
  • {The date that the synthetic tree was constructed.}
  • taxonomy_version
  • {The version of the taxonomy used to initialize the graph.}
  • num_source_studies
  • {The number of unique source trees used in the synthetic tree.}
  • num_tips
  • {The number of terminal (tip) taxa in the synthetic tree.}
  • root_taxon_name
  • {The taxonomic name of the root node of the synthetic tree.}
  • root_node_id
  • {The node ID of the root node of the synthetic tree.}
  • root_ott_id
  • {The OpenTree Taxonomy ID (ottID) of the root node of the synthetic tree.}

Details

Summary information about the current draft tree of life, including information about the list of trees and the taxonomy used to build it.

See Also

study_list to explore the list of studies used in the synthetic tree.

Examples

Run this code
res <- tol_about()
studies <- study_list(tol_about(study_list=TRUE))

Run the code above in your browser using DataLab