tol_lineage(tax, ...)
tol_node_info(ott_id = NULL, node_id = NULL, include_lineage = FALSE, ...)
"tax_rank"(tax, ...)
"tax_sources"(tax, ...)
"unique_name"(tax, ...)
"tax_name"(tax, ...)
"ott_id"(tax, ...)
"source_list"(tax, ...)
"tax_lineage"(tax, ...)
"tol_lineage"(tax, ...)tol_node_info.tol_node_info returns an invisible list of summary
information about the queried node:source_id_map below).supported_by.tol_lineage and tax_lineage return data
frames. tol_lineage indicate for each ancestor its
node identifier, the number of tips descending from that
node, and whether it corresponds to a taxonomic level.
If the argument include_lineage=TRUE is used, you can
use tax_lineage() or tol_lineage to return the
taxonomic information or the node information for all the
ancestors to this node, down to the root of the tree.
## Not run:
# birds <- tol_node_info(ott_id=81461, include_lineage=TRUE)
# source_list(birds)
# tax_rank(birds)
# ott_id(birds)
# tax_lineage(birds)
# tol_lineage(birds)## End(Not run)
Run the code above in your browser using DataLab