tol_mrca(ott_ids = NULL, node_ids = NULL, ...)
"tax_sources"(tax, ...)
"unique_name"(tax, ...)
"tax_name"(tax, ...)
"tax_rank"(tax, ...)
"ott_id"(tax, ...)
"source_list"(tax, ...)rotl for more information).tol_mrca().nearest_taxon list is returned (see below)).source_id_map below) Not all properties are
are present for every node.taxon list above is returned).mrca
list above. Source trees will have the following properties:supported_by.mrca slot, otherwise they will be in the
nearest_taxon slot of the list. If any of the specified
nodes is not in the synthetic tree an error will be returned. Taxonomic methods (tax_sources(), ott_id(),
unique_name(), ...) are availble on the objects
returned by tol_mrca(). If the MRCA node is MRTA, the
name of the object returned by these methods will start with
ott, otherwise it will start with mrca.
## Not run:
# birds_mrca <- tol_mrca(ott_ids=c(412129, 536234))
# ott_id(birds_mrca)
# tax_sources(birds_mrca)## End(Not run)
Run the code above in your browser using DataLab