the ott ids for which the MRCA is desired
(character or numeric vector)
...
additional arguments to customize the API call (see
rotl for more information).
Value
A list
Details
Get the MRCA of a set of nodes on the current synthetic
tree. Accepts any combination of node ids and ott ids as
input. Returns information about the most recent common ancestor
(MRCA) node as well as the most recent taxonomic ancestor (MRTA)
node (the closest taxonomic node to the MRCA node in the synthetic
tree; the MRCA and MRTA may be the same node). Node ids that are
not in the synthetic tree are dropped from the MRCA
calculation. For a valid ott id that is not in the synthetic tree
(i.e. it is not recovered as monophyletic from the source tree
information), the taxonomic descendants of the node are used in
the MRCA calculation. Returns any unmatched node ids / ott ids.
Return the most recent common ancestor of a set of nodes
in the synthetic tree.